
[![Enterprise Modules](https://raw.githubusercontent.com/enterprisemodules/public_images/master/banner1.jpg)](https://www.enterprisemodules.com)

#### Table of Contents

1. [Overview](#overview)
2. [License](#license)
3. [Description - What the module does and why it is useful](#description)
4. [Setup](#setup)
  * [Requirements](#requirements)
  * [Installing the zfs_appliance module](#installing-the-zfs_appliance-module)
5. [Reference - An under-the-hood peek at what the module is doing and how](#reference)
6. [Limitations - OS compatibility, etc.](#limitations)

## Overview

Enterprise Modules has a long history of providing puppet modules to products used in large enterprises. This module allows you to use puppet to manage [Oracle ZFS appliances](https://www.oracle.com/storage/nas/index.html). 

Enterprise Modules is committed to helping our customers enjoy all the benefits of Puppet and Puppet Enterprise for *all* components in the IT infrastructure of large enterprises. Also the non open-source components. This module is a strong addition to our set of modules and shows our first steps moving out of the domain of Oracle products. 

## License

This is a commercially licensed module. But you can use the module on VirtualBox based development systems for **FREE**. When used on **real** systems a license is required.

You can license our modules in multiple ways. Our basic licensing model requires a subscription per node. But [contact](https://www.enterprisemodules.com/company/contact/) us for details.

Check the [License](https://forge.puppet.com/enterprisemodules/zfs_appliance/license) for details.

## Description

The `zfs_appliance` module allows you to manage:

- `zfs_share`
- `zfs_project`

Here is an example on how to manage a ZFS project on a ZFS appliance.

```puppet
zfs_appliance { 'default':
  password      => 'welcome1',
  verify_ssl    => false,
  appliance_url => 'https://192.168.59.10:215',
}

zfs_project { 'default:all/project_1':
  ensure              => 'present',
  aclinherit          => 'restricted',
  aclmode             => 'discard',
  checksum            => 'fletcher4',
  compression         => 'off',
  default_group       => 'other',
  default_permissions => '705',
  default_user        => 'nobody',
  mountpoint          => '/export/project_1',
  quota               => '0.0',
  recordsize          => '131072.0',
  reservation         => '0.0',
  sharenfs            => 'on',
  sharesmb            => 'on',
  snapdir             => 'hidden',
}

```

Check [here](https://www.enterprisemodules.com/docs/zfs_appliance/description.html) to see the full documentation for this module.

## Setup

### Requirements

The [`zfs_appliance`](https://www.enterprisemodules.com/shop/products/puppet-zfs_appliance-module) module requires:

- Puppet module [`enterprisemodules-easy_type`](https://forge.puppet.com/enterprisemodules/easy_type) installed.
- Puppet version 4.0 or higher. Can be Puppet Enterprise or Puppet Open Source
- Access to an Oracle ZFS appliance
- A valid entitlement for usage of this module by Enterprise Modules.
- Runs on most Linux systems.
- Windows systems are **NOT** supported

### Installing the zfs_appliance module

To install these modules, you can use a `Puppetfile`

```
mod 'enterprisemodules/zfs_appliance'               ,'1.0.x'
```

Then use the `librarian-puppet` or `r10K` to install the software.

You can also install the software using the `puppet module`  command:

```
puppet module install enterprisemodules-zfs_appliance
```

## Reference

Here you can find some more information regarding this puppet module:
- [The documentation](https://www.enterprisemodules.com/docs/zfs_appliance/description.html)

There are no related blog posts yet.Some example code:


## Limitations

This module runs most Linux versions. It requires a puppet version higher than 4. The module does **NOT** run on windows systems. Contact us of you need to run this module on other flovors of UNIX. We can work together with you to make it work.