#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:quota, :parent => Puppet::Parameter::ZfsProperty) do
  include EasyType

  desc <<-EOD
    Specifies the quota on the disk or share.

        zfs_...{
          ...
          quota => '1G'
          ...
        }
  EOD

  data_type("Optional[Variant[Enum['absent'],Integer]]")

  munge do | size |
    return size if size.to_s == 'absent'
    return size if size.is_a?(Numeric)
    real_size = case size
    when /^\d*\.?\d+(K|k)$/
      @unit = 1024
      size.chop.to_f * @unit
    when /^\d*\.?\d+(M|m)$/
      @unit = 1024 * 1024
      size.chop.to_f * @unit
    when /^\d*\.?\d+(G|g)$/
      @unit = 1024 * 1024 * 1024
      size.chop.to_f * @unit
    when /^\d*\.?\d+(T|t)$/
      @unit = 1024 * 1024 * 1024 * 1024
      size.chop.to_f * @unit
    when /^\d*\.?\d+$/
      @unit = 1
      size.to_f
    else
      fail("Quota #{size} is an invalid size")
    end
    fail "Quota is #{real_size}, but needs to be greater then 133415.0" if real_size < 133415.0 and real_size != 0.0
    real_size
  end

  def insync?(is)
    (is/@unit).round(2) == (should/@unit).round(2)
  end

end
