#
# See the file "LICENSE" for the full license governing this code.
#
require 'yaml'
require 'easy_type'
$:.unshift("#{File.dirname(__FILE__)}/../..")


module Puppet
  Type.newtype(:zfs_appliance) do
    include EasyType

    SETTINGS_FILE = '/etc/zfs_appliance.yaml'

    desc <<-EOD
      This resource allows you to register ZFS appliance access. Here is an example on how to use this:

          zfs_appliance { 'default':
            password      => 'welcome1',
            verify_ssl    => false,
            appliance_url => 'https://192.168.59.10:215',
          }

      All the other zfs types use this information to connect to the Appliance. You can use this on multiple
      machines.

    EOD

    to_get_raw_resources do
      resources_from_yaml
    end

    parameter :name
    property :username
    property :password
    property :appliance_url
    property :verify_ssl

    def self.configuration
      @configuration
    end

    private

    def self.resources_from_yaml
      Puppet.debug '0 read_from_yaml '
      @configuration = read_from_yaml
      normalize(@configuration)
    end

    def self.config_file
      Pathname.new(SETTINGS_FILE).expand_path
    end

    def self.read_from_yaml
      if File.exist?(config_file)
        open(config_file) { |f| YAML.load(f) }
      else
        {}
      end
    end

    private

    def self.normalize(content)
      normalized_content = []
      content.each do | key, value|
        value[:name] = key
        normalized_content << with_hashified_keys(value)
      end
      normalized_content
    end

    def self.with_hashified_keys(hash)
      result = {}
      hash.each do |key, value|
        result[key.to_sym] = value
      end
      result
    end

  end
end
